Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2033)

Unified Diff: tests/lib/async/intercept_run_async4_test.dart

Issue 26151002: Rename runAsync to scheduleMicrotask. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Add test. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/lib/async/intercept_run_async3_test.dart ('k') | tests/lib/async/intercept_run_async5_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/lib/async/intercept_run_async4_test.dart
diff --git a/tests/lib/async/intercept_run_async4_test.dart b/tests/lib/async/intercept_run_async4_test.dart
index 30c4a276089908feef09c201bb3dd229f1bcaa49..2be31797c96d81e43b5ecbf520e3949aa3251ccf 100644
--- a/tests/lib/async/intercept_run_async4_test.dart
+++ b/tests/lib/async/intercept_run_async4_test.dart
@@ -10,9 +10,9 @@ var events = [];
body() {
events.add("body entry");
- runAsync(() {
+ scheduleMicrotask(() {
events.add("run async body");
- runAsync(() {
+ scheduleMicrotask(() {
events.add("run nested body");
});
});
@@ -21,18 +21,18 @@ body() {
handler(fun) {
events.add("handler");
- runAsync(fun);
+ scheduleMicrotask(fun);
events.add("handler done");
}
main() {
asyncStart();
- // Test that body of a runAsync goes to the zone it came from.
- var result = runZonedExperimental(body, onRunAsync: handler);
+ // Test that body of a scheduleMicrotask goes to the zone it came from.
+ var result = runZonedExperimental(body, onScheduleMicrotask: handler);
events.add("after");
- runAsync(() {
- runAsync(() {
+ scheduleMicrotask(() {
+ scheduleMicrotask(() {
Expect.listEquals(
["body entry",
"handler", "handler done",
« no previous file with comments | « tests/lib/async/intercept_run_async3_test.dart ('k') | tests/lib/async/intercept_run_async5_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698